@@ -7,6 +7,7 @@ import multiprocessing
 import os
 import sys
 import tempfile
+import glob
 try:
     from test.support import EnvironmentVarGuard
 except ImportError:
@@ -36,6 +37,7 @@ from UpdateManager.Core.MetaRelease import (
     MetaReleaseCore,
     MetaReleaseParseError,
 )
+from UpdateManager.Core.utils import url_downloadable
 
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -88,6 +90,15 @@ class TestMetaReleaseCore(unittest.TestCase):
         self.httpd_process.join()
         install_opener(None)
 
+        bin_list = glob.glob(os.path.join(CURDIR,
+                                          "aptroot-changelog/"
+                                          "var/cache/apt/*.bin"))
+        for bin_file in bin_list:
+            try:
+                os.remove(bin_file)
+            except OSError:
+                pass
+
     def testnewdist(self):
         """ test that upgrades offer the right upgrade path """
         for (current, next) in [("dapper", "hardy"),
@@ -101,6 +112,18 @@ class TestMetaReleaseCore(unittest.TestCase):
                              "but expected '%s''" % (current, new_dist.name,
                                                      next))
 
+    @unittest.skipUnless(url_downloadable(
+        "https://ubuntu.com", logging.debug),
+        "Could not reach https test site")
+    def test_https_url_downloadable(self):
+        with EnvironmentVarGuard() as environ:
+            logging.debug("no proxy, https address")
+            del environ["http_proxy"]
+            install_opener(None)
+            self.assertTrue(url_downloadable("https://ubuntu.com",
+                            logging.debug),
+                            "download https with no proxy failed")
+
     def test_url_downloadable(self):
         from UpdateManager.Core.utils import url_downloadable
         with EnvironmentVarGuard() as environ:
@@ -131,12 +154,12 @@ class TestMetaReleaseCore(unittest.TestCase):
                             logging.debug),
                             "download with no proxy failed")
 
-            logging.debug("no proxy, no valid adress")
+            logging.debug("no proxy, no valid address")
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
                                               logging.debug),
                              "download with no proxy failed")
 
-            logging.debug("proxy, no valid adress")
+            logging.debug("proxy, no valid address")
             environ["http_proxy"] = "http://localhost:%s" % self.port
             install_opener(None)
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
